@@ -1,5 +1,5 @@
 #!/bin/bash
 
-export MAVEN_OPTS=-Xmx512m
+#export MAVEN_OPTS=-Xmx1g
 #export M2_HOME=/opt/maven
 #export PATH=$PATH:$M2_HOME/bin
